# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from neurion.crucible import params_pb2 as neurion_dot_crucible_dot_params__pb2
from neurion.crucible import task_pb2 as neurion_dot_crucible_dot_task__pb2
from neurion.crucible import submission_pb2 as neurion_dot_crucible_dot_submission__pb2
from neurion.crucible import plagiarism_report_pb2 as neurion_dot_crucible_dot_plagiarism__report__pb2
from neurion.crucible import creator_application_pb2 as neurion_dot_crucible_dot_creator__application__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cneurion/crucible/query.proto\x12\x10neurion.crucible\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1dneurion/crucible/params.proto\x1a\x1bneurion/crucible/task.proto\x1a!neurion/crucible/submission.proto\x1a(neurion/crucible/plagiarism_report.proto\x1a*neurion/crucible/creator_application.proto\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x18.neurion.crucible.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x19\n\x17QueryGetCreatorsRequest\",\n\x18QueryGetCreatorsResponse\x12\x10\n\x08\x63reators\x18\x01 \x03(\t\"5\n\"QueryGetCreatorApplicationsRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\"l\n#QueryGetCreatorApplicationsResponse\x12\x45\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32$.neurion.crucible.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"!\n\x13QueryGetTaskRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"G\n\x14QueryGetTaskResponse\x12/\n\x04task\x18\x01 \x01(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryListAllTasksRequest\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\r\n\x05limit\x18\x02 \x01(\x04\"\x8a\x01\n\x19QueryListAllTasksResponse\x12\x30\n\x05tasks\x18\x01 \x03(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"l\n\x1dQueryListTasksByStatusRequest\x12,\n\x06status\x18\x01 \x01(\x0e\x32\x1c.neurion.crucible.TaskStatus\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\"\x8f\x01\n\x1eQueryListTasksByStatusResponse\x12\x30\n\x05tasks\x18\x01 \x03(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\'\n\x19QueryGetSubmissionRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"Y\n\x1aQueryGetSubmissionResponse\x12;\n\nsubmission\x18\x01 \x01(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"J\n&QueryGetSubmissionByTaskCreatorRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\"\xb7\x01\n\'QueryGetSubmissionByTaskCreatorResponse\x12\x42\n\x11\x66inal_submissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12H\n\x17provisional_submissions\x18\x02 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"2\n\x1fQueryGetSubmissionByTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"\xb0\x01\n QueryGetSubmissionByTaskResponse\x12\x42\n\x11\x66inal_submissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12H\n\x17provisional_submissions\x18\x02 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"J\n(QueryGetEncryptedProofOfOwnershipRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x11\n\tplaintext\x18\x02 \x01(\t\"?\n)QueryGetEncryptedProofOfOwnershipResponse\x12\x12\n\nciphertext\x18\x01 \x01(\t\"4\n\x1fQueryGetPlagiarismReportRequest\x12\x11\n\treport_id\x18\x01 \x01(\x04\"a\n QueryGetPlagiarismReportResponse\x12=\n\x06report\x18\x01 \x01(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\":\n\x19QueryGetTaskRewardRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\",\n\x1aQueryGetTaskRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"+\n)QueryGetPendingCreatorApplicationsRequest\"q\n*QueryGetPendingCreatorApplicationsResponse\x12\x43\n\napplicants\x18\x01 \x03(\x0b\x32$.neurion.crucible.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryGetTaskStakeRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\"*\n\x19QueryGetTaskStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\";\n(QueryGetUnscoredSubmissionsByTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"i\n)QueryGetUnscoredSubmissionsByTaskResponse\x12<\n\x0bsubmissions\x18\x01 \x03(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\xa5\x15\n\x05Query\x12w\n\x06Params\x12$.neurion.crucible.QueryParamsRequest\x1a%.neurion.crucible.QueryParamsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/neurion/crucible/params\x12\x8c\x01\n\x0bGetCreators\x12).neurion.crucible.QueryGetCreatorsRequest\x1a*.neurion.crucible.QueryGetCreatorsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/neurion/crucible/get_creators\x12\xc3\x01\n\x16GetCreatorApplications\x12\x34.neurion.crucible.QueryGetCreatorApplicationsRequest\x1a\x35.neurion.crucible.QueryGetCreatorApplicationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/neurion/crucible/get_creator_applications/{creator}\x12\x81\x01\n\x07GetTask\x12%.neurion.crucible.QueryGetTaskRequest\x1a&.neurion.crucible.QueryGetTaskResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/neurion/crucible/get_task/{id}\x12\xa2\x01\n\x0cListAllTasks\x12*.neurion.crucible.QueryListAllTasksRequest\x1a+.neurion.crucible.QueryListAllTasksResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/neurion/crucible/list_all_tasks/{offset}/{limit}\x12\xc0\x01\n\x11ListTasksByStatus\x12/.neurion.crucible.QueryListTasksByStatusRequest\x1a\x30.neurion.crucible.QueryListTasksByStatusResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/neurion/crucible/list_tasks_by_status/{status}/{offset}/{limit}\x12\x99\x01\n\rGetSubmission\x12+.neurion.crucible.QueryGetSubmissionRequest\x1a,.neurion.crucible.QueryGetSubmissionResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/neurion/crucible/get_submission/{id}\x12\xdf\x01\n\x1aGetSubmissionByTaskCreator\x12\x38.neurion.crucible.QueryGetSubmissionByTaskCreatorRequest\x1a\x39.neurion.crucible.QueryGetSubmissionByTaskCreatorResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/crucible/get_submission_by_task_creator/{task_id}/{creator}\x12\xb8\x01\n\x13GetSubmissionByTask\x12\x31.neurion.crucible.QueryGetSubmissionByTaskRequest\x1a\x32.neurion.crucible.QueryGetSubmissionByTaskResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_submission_by_task/{task_id}\x12\xe5\x01\n\x1cGetEncryptedProofOfOwnership\x12:.neurion.crucible.QueryGetEncryptedProofOfOwnershipRequest\x1a;.neurion.crucible.QueryGetEncryptedProofOfOwnershipResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/neurion/crucible/get_encrypted_proof_of_ownership/{key}/{plaintext}\x12\xb9\x01\n\x13GetPlagiarismReport\x12\x31.neurion.crucible.QueryGetPlagiarismReportRequest\x1a\x32.neurion.crucible.QueryGetPlagiarismReportResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/neurion/crucible/get_plagiarism_report/{report_id}\x12\xa6\x01\n\rGetTaskReward\x12+.neurion.crucible.QueryGetTaskRewardRequest\x1a,.neurion.crucible.QueryGetTaskRewardResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_task_reward/{task_id}/{user}\x12\xd6\x01\n\x1dGetPendingCreatorApplications\x12;.neurion.crucible.QueryGetPendingCreatorApplicationsRequest\x1a<.neurion.crucible.QueryGetPendingCreatorApplicationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/neurion/crucible/get_pending_creator_applications\x12\xa2\x01\n\x0cGetTaskStake\x12*.neurion.crucible.QueryGetTaskStakeRequest\x1a+.neurion.crucible.QueryGetTaskStakeResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/neurion/crucible/get_task_stake/{task_id}/{user}\x12\xdd\x01\n\x1cGetUnscoredSubmissionsByTask\x12:.neurion.crucible.QueryGetUnscoredSubmissionsByTaskRequest\x1a;.neurion.crucible.QueryGetUnscoredSubmissionsByTaskResponse\"D\x82\xd3\xe4\x93\x02>\x12</neurion/crucible/get_unscored_submissions_by_task/{task_id}B\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applications']._loaded_options = None
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE'].fields_by_name['applications']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTALLTASKSRESPONSE'].fields_by_name['tasks']._loaded_options = None
  _globals['_QUERYLISTALLTASKSRESPONSE'].fields_by_name['tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE'].fields_by_name['tasks']._loaded_options = None
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE'].fields_by_name['tasks']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONRESPONSE'].fields_by_name['submission']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONRESPONSE'].fields_by_name['submission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['final_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['final_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['provisional_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE'].fields_by_name['provisional_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['final_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['final_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['provisional_submissions']._loaded_options = None
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE'].fields_by_name['provisional_submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._loaded_options = None
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE'].fields_by_name['submissions']._loaded_options = None
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE'].fields_by_name['submissions']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\032\022\030/neurion/crucible/params'
  _globals['_QUERY'].methods_by_name['GetCreators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreators']._serialized_options = b'\202\323\344\223\002 \022\036/neurion/crucible/get_creators'
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreatorApplications']._serialized_options = b'\202\323\344\223\0026\0224/neurion/crucible/get_creator_applications/{creator}'
  _globals['_QUERY'].methods_by_name['GetTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002!\022\037/neurion/crucible/get_task/{id}'
  _globals['_QUERY'].methods_by_name['ListAllTasks']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListAllTasks']._serialized_options = b'\202\323\344\223\0023\0221/neurion/crucible/list_all_tasks/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['ListTasksByStatus']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListTasksByStatus']._serialized_options = b'\202\323\344\223\002B\022@/neurion/crucible/list_tasks_by_status/{status}/{offset}/{limit}'
  _globals['_QUERY'].methods_by_name['GetSubmission']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmission']._serialized_options = b'\202\323\344\223\002\'\022%/neurion/crucible/get_submission/{id}'
  _globals['_QUERY'].methods_by_name['GetSubmissionByTaskCreator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmissionByTaskCreator']._serialized_options = b'\202\323\344\223\002F\022D/neurion/crucible/get_submission_by_task_creator/{task_id}/{creator}'
  _globals['_QUERY'].methods_by_name['GetSubmissionByTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetSubmissionByTask']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_submission_by_task/{task_id}'
  _globals['_QUERY'].methods_by_name['GetEncryptedProofOfOwnership']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetEncryptedProofOfOwnership']._serialized_options = b'\202\323\344\223\002F\022D/neurion/crucible/get_encrypted_proof_of_ownership/{key}/{plaintext}'
  _globals['_QUERY'].methods_by_name['GetPlagiarismReport']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPlagiarismReport']._serialized_options = b'\202\323\344\223\0025\0223/neurion/crucible/get_plagiarism_report/{report_id}'
  _globals['_QUERY'].methods_by_name['GetTaskReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskReward']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_task_reward/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._serialized_options = b'\202\323\344\223\0024\0222/neurion/crucible/get_pending_creator_applications'
  _globals['_QUERY'].methods_by_name['GetTaskStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskStake']._serialized_options = b'\202\323\344\223\0023\0221/neurion/crucible/get_task_stake/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetUnscoredSubmissionsByTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetUnscoredSubmissionsByTask']._serialized_options = b'\202\323\344\223\002>\022</neurion/crucible/get_unscored_submissions_by_task/{task_id}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=346
  _globals['_QUERYPARAMSREQUEST']._serialized_end=366
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=368
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=442
  _globals['_QUERYGETCREATORSREQUEST']._serialized_start=444
  _globals['_QUERYGETCREATORSREQUEST']._serialized_end=469
  _globals['_QUERYGETCREATORSRESPONSE']._serialized_start=471
  _globals['_QUERYGETCREATORSRESPONSE']._serialized_end=515
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_start=517
  _globals['_QUERYGETCREATORAPPLICATIONSREQUEST']._serialized_end=570
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_start=572
  _globals['_QUERYGETCREATORAPPLICATIONSRESPONSE']._serialized_end=680
  _globals['_QUERYGETTASKREQUEST']._serialized_start=682
  _globals['_QUERYGETTASKREQUEST']._serialized_end=715
  _globals['_QUERYGETTASKRESPONSE']._serialized_start=717
  _globals['_QUERYGETTASKRESPONSE']._serialized_end=788
  _globals['_QUERYLISTALLTASKSREQUEST']._serialized_start=790
  _globals['_QUERYLISTALLTASKSREQUEST']._serialized_end=847
  _globals['_QUERYLISTALLTASKSRESPONSE']._serialized_start=850
  _globals['_QUERYLISTALLTASKSRESPONSE']._serialized_end=988
  _globals['_QUERYLISTTASKSBYSTATUSREQUEST']._serialized_start=990
  _globals['_QUERYLISTTASKSBYSTATUSREQUEST']._serialized_end=1098
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE']._serialized_start=1101
  _globals['_QUERYLISTTASKSBYSTATUSRESPONSE']._serialized_end=1244
  _globals['_QUERYGETSUBMISSIONREQUEST']._serialized_start=1246
  _globals['_QUERYGETSUBMISSIONREQUEST']._serialized_end=1285
  _globals['_QUERYGETSUBMISSIONRESPONSE']._serialized_start=1287
  _globals['_QUERYGETSUBMISSIONRESPONSE']._serialized_end=1376
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORREQUEST']._serialized_start=1378
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORREQUEST']._serialized_end=1452
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE']._serialized_start=1455
  _globals['_QUERYGETSUBMISSIONBYTASKCREATORRESPONSE']._serialized_end=1638
  _globals['_QUERYGETSUBMISSIONBYTASKREQUEST']._serialized_start=1640
  _globals['_QUERYGETSUBMISSIONBYTASKREQUEST']._serialized_end=1690
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE']._serialized_start=1693
  _globals['_QUERYGETSUBMISSIONBYTASKRESPONSE']._serialized_end=1869
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPREQUEST']._serialized_start=1871
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPREQUEST']._serialized_end=1945
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPRESPONSE']._serialized_start=1947
  _globals['_QUERYGETENCRYPTEDPROOFOFOWNERSHIPRESPONSE']._serialized_end=2010
  _globals['_QUERYGETPLAGIARISMREPORTREQUEST']._serialized_start=2012
  _globals['_QUERYGETPLAGIARISMREPORTREQUEST']._serialized_end=2064
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE']._serialized_start=2066
  _globals['_QUERYGETPLAGIARISMREPORTRESPONSE']._serialized_end=2163
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_start=2165
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_end=2223
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_start=2225
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_end=2269
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_start=2271
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_end=2314
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_start=2316
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_end=2429
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_start=2431
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_end=2488
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_start=2490
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_end=2532
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKREQUEST']._serialized_start=2534
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKREQUEST']._serialized_end=2593
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE']._serialized_start=2595
  _globals['_QUERYGETUNSCOREDSUBMISSIONSBYTASKRESPONSE']._serialized_end=2700
  _globals['_QUERY']._serialized_start=2703
  _globals['_QUERY']._serialized_end=5428
# @@protoc_insertion_point(module_scope)
