# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/bank/v1beta1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/bank/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/bank/v1beta1/query.proto\x12\x13\x63osmos.bank.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\"?\n\x13QueryBalanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"B\n\x14QueryBalanceResponse\x12*\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.Coin\"p\n\x17QueryAllBalancesRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb6\x01\n\x18QueryAllBalancesResponse\x12]\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"_\n\x17QueryTotalSupplyRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb4\x01\n\x18QueryTotalSupplyResponse\x12[\n\x06supply\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"%\n\x14QuerySupplyOfRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"H\n\x15QuerySupplyOfResponse\x12/\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x1b.cosmos.bank.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"X\n\x1aQueryDenomsMetadataRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x92\x01\n\x1bQueryDenomsMetadataResponse\x12\x36\n\tmetadatas\x18\x01 \x03(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"*\n\x19QueryDenomMetadataRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"S\n\x1aQueryDenomMetadataResponse\x12\x35\n\x08metadata\x18\x01 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x00\x32\xb3\x08\n\x05Query\x12\x98\x01\n\x07\x42\x61lance\x12(.cosmos.bank.v1beta1.QueryBalanceRequest\x1a).cosmos.bank.v1beta1.QueryBalanceResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/bank/v1beta1/balances/{address}/by_denom\x12\x9b\x01\n\x0b\x41llBalances\x12,.cosmos.bank.v1beta1.QueryAllBalancesRequest\x1a-.cosmos.bank.v1beta1.QueryAllBalancesResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/bank/v1beta1/balances/{address}\x12\x8f\x01\n\x0bTotalSupply\x12,.cosmos.bank.v1beta1.QueryTotalSupplyRequest\x1a-.cosmos.bank.v1beta1.QueryTotalSupplyResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/supply\x12\x8e\x01\n\x08SupplyOf\x12).cosmos.bank.v1beta1.QuerySupplyOfRequest\x1a*.cosmos.bank.v1beta1.QuerySupplyOfResponse\"+\x82\xd3\xe4\x93\x02%\x12#/cosmos/bank/v1beta1/supply/{denom}\x12\x80\x01\n\x06Params\x12\'.cosmos.bank.v1beta1.QueryParamsRequest\x1a(.cosmos.bank.v1beta1.QueryParamsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/bank/v1beta1/params\x12\xa6\x01\n\rDenomMetadata\x12..cosmos.bank.v1beta1.QueryDenomMetadataRequest\x1a/.cosmos.bank.v1beta1.QueryDenomMetadataResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmos/bank/v1beta1/denoms_metadata/{denom}\x12\xa1\x01\n\x0e\x44\x65nomsMetadata\x12/.cosmos.bank.v1beta1.QueryDenomsMetadataRequest\x1a\x30.cosmos.bank.v1beta1.QueryDenomsMetadataResponse\",\x82\xd3\xe4\x93\x02&\x12$/cosmos/bank/v1beta1/denoms_metadataB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.bank.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _globals['_QUERYBALANCEREQUEST']._loaded_options = None
  _globals['_QUERYBALANCEREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYALLBALANCESREQUEST']._loaded_options = None
  _globals['_QUERYALLBALANCESREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYALLBALANCESRESPONSE'].fields_by_name['balances']._loaded_options = None
  _globals['_QUERYALLBALANCESRESPONSE'].fields_by_name['balances']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_QUERYTOTALSUPPLYREQUEST']._loaded_options = None
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYTOTALSUPPLYRESPONSE'].fields_by_name['supply']._loaded_options = None
  _globals['_QUERYTOTALSUPPLYRESPONSE'].fields_by_name['supply']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_QUERYSUPPLYOFRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYSUPPLYOFRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDENOMSMETADATARESPONSE'].fields_by_name['metadatas']._loaded_options = None
  _globals['_QUERYDENOMSMETADATARESPONSE'].fields_by_name['metadatas']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDENOMMETADATARESPONSE'].fields_by_name['metadata']._loaded_options = None
  _globals['_QUERYDENOMMETADATARESPONSE'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Balance']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Balance']._serialized_options = b'\202\323\344\223\0022\0220/cosmos/bank/v1beta1/balances/{address}/by_denom'
  _globals['_QUERY'].methods_by_name['AllBalances']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllBalances']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/bank/v1beta1/balances/{address}'
  _globals['_QUERY'].methods_by_name['TotalSupply']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TotalSupply']._serialized_options = b'\202\323\344\223\002\035\022\033/cosmos/bank/v1beta1/supply'
  _globals['_QUERY'].methods_by_name['SupplyOf']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SupplyOf']._serialized_options = b'\202\323\344\223\002%\022#/cosmos/bank/v1beta1/supply/{denom}'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\035\022\033/cosmos/bank/v1beta1/params'
  _globals['_QUERY'].methods_by_name['DenomMetadata']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomMetadata']._serialized_options = b'\202\323\344\223\002.\022,/cosmos/bank/v1beta1/denoms_metadata/{denom}'
  _globals['_QUERY'].methods_by_name['DenomsMetadata']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomsMetadata']._serialized_options = b'\202\323\344\223\002&\022$/cosmos/bank/v1beta1/denoms_metadata'
  _globals['_QUERYBALANCEREQUEST']._serialized_start=216
  _globals['_QUERYBALANCEREQUEST']._serialized_end=279
  _globals['_QUERYBALANCERESPONSE']._serialized_start=281
  _globals['_QUERYBALANCERESPONSE']._serialized_end=347
  _globals['_QUERYALLBALANCESREQUEST']._serialized_start=349
  _globals['_QUERYALLBALANCESREQUEST']._serialized_end=461
  _globals['_QUERYALLBALANCESRESPONSE']._serialized_start=464
  _globals['_QUERYALLBALANCESRESPONSE']._serialized_end=646
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_start=648
  _globals['_QUERYTOTALSUPPLYREQUEST']._serialized_end=743
  _globals['_QUERYTOTALSUPPLYRESPONSE']._serialized_start=746
  _globals['_QUERYTOTALSUPPLYRESPONSE']._serialized_end=926
  _globals['_QUERYSUPPLYOFREQUEST']._serialized_start=928
  _globals['_QUERYSUPPLYOFREQUEST']._serialized_end=965
  _globals['_QUERYSUPPLYOFRESPONSE']._serialized_start=967
  _globals['_QUERYSUPPLYOFRESPONSE']._serialized_end=1039
  _globals['_QUERYPARAMSREQUEST']._serialized_start=1041
  _globals['_QUERYPARAMSREQUEST']._serialized_end=1061
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=1063
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=1135
  _globals['_QUERYDENOMSMETADATAREQUEST']._serialized_start=1137
  _globals['_QUERYDENOMSMETADATAREQUEST']._serialized_end=1225
  _globals['_QUERYDENOMSMETADATARESPONSE']._serialized_start=1228
  _globals['_QUERYDENOMSMETADATARESPONSE']._serialized_end=1374
  _globals['_QUERYDENOMMETADATAREQUEST']._serialized_start=1376
  _globals['_QUERYDENOMMETADATAREQUEST']._serialized_end=1418
  _globals['_QUERYDENOMMETADATARESPONSE']._serialized_start=1420
  _globals['_QUERYDENOMMETADATARESPONSE']._serialized_end=1503
  _globals['_QUERY']._serialized_start=1506
  _globals['_QUERY']._serialized_end=2581
# @@protoc_insertion_point(module_scope)
