# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/fusion/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/fusion/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from neurion.fusion import params_pb2 as neurion_dot_fusion_dot_params__pb2
from neurion.fusion import task_pb2 as neurion_dot_fusion_dot_task__pb2
from neurion.fusion import creator_application_pb2 as neurion_dot_fusion_dot_creator__application__pb2
from neurion.fusion import proposed_model_pb2 as neurion_dot_fusion_dot_proposed__model__pb2
from neurion.fusion import validation_task_pb2 as neurion_dot_fusion_dot_validation__task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aneurion/fusion/query.proto\x12\x0eneurion.fusion\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bneurion/fusion/params.proto\x1a\x19neurion/fusion/task.proto\x1a(neurion/fusion/creator_application.proto\x1a#neurion/fusion/proposed_model.proto\x1a$neurion/fusion/validation_task.proto\"\x14\n\x12QueryParamsRequest\"H\n\x13QueryParamsResponse\x12\x31\n\x06params\x18\x01 \x01(\x0b\x32\x16.neurion.fusion.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"&\n\x13QueryGetTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\"E\n\x14QueryGetTaskResponse\x12-\n\x04task\x18\x01 \x01(\x0b\x32\x14.neurion.fusion.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\":\n\x19QueryGetTaskRewardRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\",\n\x1aQueryGetTaskRewardResponse\x12\x0e\n\x06reward\x18\x01 \x01(\x04\"3\n QueryGetCreatorApplicantsRequest\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\"f\n!QueryGetCreatorApplicantsResponse\x12\x41\n\napplicants\x18\x01 \x03(\x0b\x32\".neurion.fusion.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"+\n)QueryGetPendingCreatorApplicationsRequest\"o\n*QueryGetPendingCreatorApplicationsResponse\x12\x41\n\napplicants\x18\x01 \x03(\x0b\x32\".neurion.fusion.CreatorApplicationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\">\n\x1cQueryGetModelsByRoundRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\r\n\x05round\x18\x02 \x01(\x04\"Y\n\x1dQueryGetModelsByRoundResponse\x12\x38\n\x06models\x18\x01 \x03(\x0b\x32\x1d.neurion.fusion.ProposedModelB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"9\n\x18QueryGetTaskStakeRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\t\"*\n\x19QueryGetTaskStakeResponse\x12\r\n\x05stake\x18\x01 \x01(\x04\"+\n\x1dQueryGetValidationTaskRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"d\n\x1eQueryGetValidationTaskResponse\x12\x42\n\x0fvalidation_task\x18\x01 \x01(\x0b\x32\x1e.neurion.fusion.ValidationTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\x91\n\n\x05Query\x12q\n\x06Params\x12\".neurion.fusion.QueryParamsRequest\x1a#.neurion.fusion.QueryParamsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/neurion/fusion/params\x12\x80\x01\n\x07GetTask\x12#.neurion.fusion.QueryGetTaskRequest\x1a$.neurion.fusion.QueryGetTaskResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/neurion/fusion/get_task/{task_id}\x12\xa0\x01\n\rGetTaskReward\x12).neurion.fusion.QueryGetTaskRewardRequest\x1a*.neurion.fusion.QueryGetTaskRewardResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/fusion/get_task_reward/{task_id}/{user}\x12\xb5\x01\n\x14GetCreatorApplicants\x12\x30.neurion.fusion.QueryGetCreatorApplicantsRequest\x1a\x31.neurion.fusion.QueryGetCreatorApplicantsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/fusion/get_creator_applicants/{creator}\x12\xd0\x01\n\x1dGetPendingCreatorApplications\x12\x39.neurion.fusion.QueryGetPendingCreatorApplicationsRequest\x1a:.neurion.fusion.QueryGetPendingCreatorApplicationsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/neurion/fusion/get_pending_creator_applications\x12\xae\x01\n\x10GetModelsByRound\x12,.neurion.fusion.QueryGetModelsByRoundRequest\x1a-.neurion.fusion.QueryGetModelsByRoundResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/neurion/fusion/get_models_by_round/{task_id}/{round}\x12\x8b\x01\n\x0cGetTaskStake\x12(.neurion.fusion.QueryGetTaskStakeRequest\x1a).neurion.fusion.QueryGetTaskStakeResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/neurion/fusion/get_task_stake\x12\xa4\x01\n\x11GetValidationTask\x12-.neurion.fusion.QueryGetValidationTaskRequest\x1a..neurion.fusion.QueryGetValidationTaskResponse\"0\x82\xd3\xe4\x93\x02*\x12(/neurion/fusion/get_validation_task/{id}B\x18Z\x16neurion/x/fusion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.fusion.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\026neurion/x/fusion/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_QUERYGETTASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETCREATORAPPLICANTSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETCREATORAPPLICANTSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._loaded_options = None
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE'].fields_by_name['applicants']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETMODELSBYROUNDRESPONSE'].fields_by_name['models']._loaded_options = None
  _globals['_QUERYGETMODELSBYROUNDRESPONSE'].fields_by_name['models']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYGETVALIDATIONTASKRESPONSE'].fields_by_name['validation_task']._loaded_options = None
  _globals['_QUERYGETVALIDATIONTASKRESPONSE'].fields_by_name['validation_task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\030\022\026/neurion/fusion/params'
  _globals['_QUERY'].methods_by_name['GetTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002$\022\"/neurion/fusion/get_task/{task_id}'
  _globals['_QUERY'].methods_by_name['GetTaskReward']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskReward']._serialized_options = b'\202\323\344\223\0022\0220/neurion/fusion/get_task_reward/{task_id}/{user}'
  _globals['_QUERY'].methods_by_name['GetCreatorApplicants']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetCreatorApplicants']._serialized_options = b'\202\323\344\223\0022\0220/neurion/fusion/get_creator_applicants/{creator}'
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetPendingCreatorApplications']._serialized_options = b'\202\323\344\223\0022\0220/neurion/fusion/get_pending_creator_applications'
  _globals['_QUERY'].methods_by_name['GetModelsByRound']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetModelsByRound']._serialized_options = b'\202\323\344\223\0027\0225/neurion/fusion/get_models_by_round/{task_id}/{round}'
  _globals['_QUERY'].methods_by_name['GetTaskStake']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetTaskStake']._serialized_options = b'\202\323\344\223\002 \022\036/neurion/fusion/get_task_stake'
  _globals['_QUERY'].methods_by_name['GetValidationTask']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GetValidationTask']._serialized_options = b'\202\323\344\223\002*\022(/neurion/fusion/get_validation_task/{id}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=290
  _globals['_QUERYPARAMSREQUEST']._serialized_end=310
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=312
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=384
  _globals['_QUERYGETTASKREQUEST']._serialized_start=386
  _globals['_QUERYGETTASKREQUEST']._serialized_end=424
  _globals['_QUERYGETTASKRESPONSE']._serialized_start=426
  _globals['_QUERYGETTASKRESPONSE']._serialized_end=495
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_start=497
  _globals['_QUERYGETTASKREWARDREQUEST']._serialized_end=555
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_start=557
  _globals['_QUERYGETTASKREWARDRESPONSE']._serialized_end=601
  _globals['_QUERYGETCREATORAPPLICANTSREQUEST']._serialized_start=603
  _globals['_QUERYGETCREATORAPPLICANTSREQUEST']._serialized_end=654
  _globals['_QUERYGETCREATORAPPLICANTSRESPONSE']._serialized_start=656
  _globals['_QUERYGETCREATORAPPLICANTSRESPONSE']._serialized_end=758
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_start=760
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSREQUEST']._serialized_end=803
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_start=805
  _globals['_QUERYGETPENDINGCREATORAPPLICATIONSRESPONSE']._serialized_end=916
  _globals['_QUERYGETMODELSBYROUNDREQUEST']._serialized_start=918
  _globals['_QUERYGETMODELSBYROUNDREQUEST']._serialized_end=980
  _globals['_QUERYGETMODELSBYROUNDRESPONSE']._serialized_start=982
  _globals['_QUERYGETMODELSBYROUNDRESPONSE']._serialized_end=1071
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_start=1073
  _globals['_QUERYGETTASKSTAKEREQUEST']._serialized_end=1130
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_start=1132
  _globals['_QUERYGETTASKSTAKERESPONSE']._serialized_end=1174
  _globals['_QUERYGETVALIDATIONTASKREQUEST']._serialized_start=1176
  _globals['_QUERYGETVALIDATIONTASKREQUEST']._serialized_end=1219
  _globals['_QUERYGETVALIDATIONTASKRESPONSE']._serialized_start=1221
  _globals['_QUERYGETVALIDATIONTASKRESPONSE']._serialized_end=1321
  _globals['_QUERY']._serialized_start=1324
  _globals['_QUERY']._serialized_end=2621
# @@protoc_insertion_point(module_scope)
